@@ -195,7 +195,6 @@ LogEvent(WORD wEventType, DWORD dwEventID, ...)
     case MSG_SERVICE_ERROR_STOP:
     case MSG_CRYPT_OFF:
     case MSG_CRYPT_ON:
-    case MSG_SMB_RESET_ALL_VCS:
 	break;
     case MSG_FLUSH_BAD_SHARE_NAME:
     case MSG_FLUSH_OPEN_ENUM_ERROR:
@@ -290,6 +289,19 @@ LogEvent(WORD wEventType, DWORD dwEventID, ...)
 	lpArgs[1] = lpStrings[1];
 	lpArgs[2] = va_arg(listArgs,LPTSTR);
     	break;
+    case MSG_DIRTY_BUFFER_AT_SHUTDOWN:
+	wNumArgs = 6;
+	lpArgs[0] = va_arg(listArgs, LPTSTR);
+        lpArgs[1] = va_arg(listArgs, LPTSTR);
+	StringCbPrintf(lpStrings[2],STRLEN,"%u",va_arg(listArgs,int));
+	StringCbPrintf(lpStrings[3],STRLEN,"%u",va_arg(listArgs,int));
+	StringCbPrintf(lpStrings[4],STRLEN,"%I64u",va_arg(listArgs,afs_int64));
+	StringCbPrintf(lpStrings[5],STRLEN,"%I64u",va_arg(listArgs,afs_int64));
+	lpArgs[2] = lpStrings[2];
+	lpArgs[3] = lpStrings[3];
+	lpArgs[4] = lpStrings[4];
+	lpArgs[5] = lpStrings[5];
+    	break;
     }
     va_end(listArgs);
 
