@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2003 SkyRope, LLC
+* Copyright (c) 2004, 2005, 2006, 2007 Secure Endpoints Inc.
+* Copyright (c) 2003 SkyRope, LLC
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without 
@@ -61,6 +62,10 @@
 #ifdef USE_MS2MIT
 #define SECURITY_WIN32
 #include <security.h>
+#if _WIN32_WINNT < 0x0501
+#undef _WIN32_WINNT
+#define _WIN32_WINNT 0x0501
+#endif
 #include <ntsecapi.h>
 #endif /* USE_MS2MIT */
 #include <stdio.h>
@@ -91,7 +96,6 @@ typedef afs_int32 errcode_t;
 #include <loadfuncs-profile.h>
 #include <loadfuncs-krb.h>
 #include <loadfuncs-krb524.h>
-#include <loadfuncs-afs36.h>
 #include <loadfuncs-leash.h>
 
 // service definitions
@@ -104,6 +108,7 @@ typedef BOOL (WINAPI *FP_CloseServiceHandle)(SC_HANDLE);
 #define KRB5_DEFAULT_LIFE            60*60*10 /* 10 hours */
 #define LSA_CCNAME                   "MSLSA:"
 
+#ifndef KTC_ERROR
 #define KTC_ERROR      11862784L
 #define KTC_TOOBIG     11862785L
 #define KTC_INVAL      11862786L
@@ -112,6 +117,7 @@ typedef BOOL (WINAPI *FP_CloseServiceHandle)(SC_HANDLE);
 #define KTC_NOPIOCTL   11862789L
 #define KTC_NOCELL     11862790L
 #define KTC_NOCM       11862791L
+#endif
 
 /* User Query data structures and functions */
 
@@ -229,7 +235,12 @@ cc_free_NC_info,
                             //    cc_get_cache_names().  set to NULL on return
     )
 );
+
+#ifdef _WIN64
+#define CCAPI_DLL   "krbcc64.dll"
+#else
 #define CCAPI_DLL   "krbcc32.dll"
+#endif
 
 /* Function Prototypes */
 DWORD GetServiceStatus(LPSTR, LPSTR, DWORD *);
@@ -248,5 +259,5 @@ int  KFW_AFS_unlog(void);
 int  KFW_AFS_klog(krb5_context, krb5_ccache, char*, char*, char*, int, char*);
 void KFW_import_ccache_data(void);
 BOOL MSLSA_IsKerberosLogon();
-char *afs_realm_of_cell(struct afsconf_cell *);
+char *afs_realm_of_cell(krb5_context, struct afsconf_cell *);
 #endif /* AFSKFW_INT_H */
