@@ -21,7 +21,7 @@ typedef struct chservinfo {
 } chservinfo_t;
 
 struct gaginfo {
-	unsigned long showflags, logflags, logwritethruflag, spare[3];
+	afs_uint32 showflags, logflags, logwritethruflag, spare[3];
         unsigned char spare2[128];
 };
 
@@ -41,11 +41,6 @@ struct sbstruct {
         int sb_default;
 };
 
-#define CM_IOCTLCACHEPARMS		16
-typedef struct cm_cacheParms {
-	long parms[CM_IOCTLCACHEPARMS];
-} cm_cacheParms_t;
-
 /* set cell flags */
 #define CM_SETCELLFLAG_SUID		2
 
@@ -96,4 +91,22 @@ typedef struct cm_cacheParms {
 #define VIOCGETOWNER                    0x2d
 #define VIOC_RXSTAT_PROC                0x2e
 #define VIOC_RXSTAT_PEER                0x2f
+#define VIOC_UUIDCTL                    0x30
+#define VIOC_PATH_AVAILABILITY          0x31
+#define VIOC_GETFILETYPE                0x32
+#define VIOC_UNICODECTL                 0x33
+#define VIOC_SETOWNER                   0x34
+#define VIOC_SETGROUP                   0x35
+#define VIOC_FS_CMD                     0x36
+
+#define VIOC_VOLSTAT_TEST               0x3F
+
+/* magic file name for ioctl opens */
+#define CM_IOCTL_FILENAME	"\\_._AFS_IOCTL_._"	/* double backslashes for C compiler */
+#define CM_IOCTL_FILENAME_NOSLASH "_._AFS_IOCTL_._"
+
+/* max parms for ioctl, in either direction */
+#define CM_IOCTL_MAXDATA	        8192*2
+#define CM_IOCTL_MAXPROCS               64
+
 #endif /*  __SMB_IOCONS_H_ENV_ */
