@@ -14,8 +14,10 @@
  */
 #ifdef KDUMP_KERNEL
 #include <afs/afs_args.h>
+#include <afs/afs_consts.h>
 #else
 #include "afs/afs_args.h"
+#include "afs/afs_consts.h"
 #endif
 
 /*
@@ -69,9 +71,6 @@ extern int afs_shuttingdown;
 
 /* The basic defines for the Andrew file system
     better keep things powers of two so "& (foo-1)" hack works for masking bits */
-#define	MAXHOSTS	13	/* max hosts per single volume */
-#define	OMAXHOSTS	 8	/* backwards compatibility */
-#define MAXCELLHOSTS	 8	/* max vldb servers per cell */
 #define	NBRS		15	/* max number of queued daemon requests */
 #define	NUSERS		16	/* hash table size for unixuser table */
 #define	NSERVERS	16	/* hash table size for server table */
@@ -240,7 +239,7 @@ struct vrequest {
     char permWriteError;	/* fileserver returns permenent error. */
     char tokenError;            /* a token error other than expired. */
     char idleError;             /* the server idled too long */
-    char skipserver[MAXHOSTS];
+    char skipserver[AFS_MAXHOSTS];
 };
 #define VOLMISSING 1
 #define VOLBUSY 2
@@ -273,7 +272,7 @@ struct cell {
     char *cellName;		/* char string name of cell */
     afs_int32 cellIndex;	/* sequence number */
     afs_int32 cellNum;		/* semi-permanent cell number */
-    struct server *cellHosts[MAXCELLHOSTS];	/* volume *location* hosts */
+    struct server *cellHosts[AFS_MAXCELLHOSTS];	/* volume *location* hosts */
     struct cell *lcellp;	/* Associated linked cell */
     u_short fsport;		/* file server port */
     u_short vlport;		/* volume server port */
@@ -514,8 +513,8 @@ struct volume {
     afs_rwlock_t lock;		/* the lock for this structure */
     afs_int32 volume;		/* This volume's ID number. */
     char *name;			/* This volume's name, or 0 if unknown */
-    struct server *serverHost[MAXHOSTS];	/* servers serving this volume */
-    enum repstate status[MAXHOSTS];	/* busy, offline, etc */
+    struct server *serverHost[AFS_MAXHOSTS];	/* servers serving this volume */
+    enum repstate status[AFS_MAXHOSTS];	/* busy, offline, etc */
     struct VenusFid dotdot;	/* dir to access as .. */
     struct VenusFid mtpoint;	/* The mount point for this volume. */
     afs_int32 rootVnode, rootUnique;	/* Volume's root fid */
@@ -1070,7 +1069,6 @@ typedef union {
     afs_mem_dcache_id_t mem;
 } afs_dcache_id_t;
 
-#ifdef KERNEL
 /* it does not compile outside kernel */
 struct buffer {
   afs_int32 fid;              /* is adc->index, the cache file number */
@@ -1083,9 +1081,6 @@ struct buffer {
   char lockers;
   char dirty;
   char hashIndex;
-#if defined(AFS_USEBUFFERS)
-  struct buf *bufp;
-#endif
   afs_rwlock_t lock;          /* the lock for this structure */
 };
 
@@ -1099,7 +1094,6 @@ struct fcache {
     afs_int32 chunkBytes;	/* Num bytes in this chunk */
     char states;		/* Has this chunk been modified? */
 };
-#endif
 
 /* magic numbers to specify the cache type */
 
@@ -1351,13 +1345,21 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
 #endif
 #endif
 
-#if !defined(UKERNEL) && !defined(HAVE_STRUCT_BUF)
 /* declare something so that prototypes don't flip out */
 /* appears struct buf stuff is only actually passed around as a pointer, 
    except with libuafs, in which case it is actually defined */
 
 struct buf;
-#endif
+
+struct rxfs_storeVariables {
+    struct rx_call *call;
+    struct vcache *vcache;
+    char *tbuffer;
+    struct iovec *tiov;
+    afs_int32 tnio;
+    afs_int32 hasNo64bit;
+    struct AFSStoreStatus InStatus;
+};
 
 struct storeOps {
     int (*prepare)(void *rock, afs_uint32 size, afs_uint32 *bytestoxfer);
@@ -1369,6 +1371,8 @@ struct storeOps {
     int (*close)(void *rock, struct AFSFetchStatus *OutStatus,
         afs_int32 *doProcessFS);
     int (*destroy)(void **rock, afs_int32 error);
+    int (*storeproc)(struct storeOps *, void *, struct dcache *, int *,
+		     afs_size_t *);
 };
 
 struct fetchOps {
