@@ -33,7 +33,6 @@ afs_rwlock_t afs_xcell;		/* Export for cmdebug peeking at locks */
  * afs_LookupAFSDB: look up AFSDB for given cell name and create locally
  */
 
-#ifdef AFS_AFSDB_ENV
 afs_rwlock_t afsdb_client_lock;	/* Serializes client requests */
 afs_rwlock_t afsdb_req_lock;	/* Serializes client requests */
 static char afsdb_handler_running;	/* Protected by GLOCK */
@@ -75,7 +74,7 @@ int
 afs_AFSDBHandler(char *acellName, int acellNameLen, afs_int32 * kernelMsg)
 {
     afs_int32 timeout, code;
-    afs_int32 cellHosts[MAXCELLHOSTS];
+    afs_int32 cellHosts[AFS_MAXCELLHOSTS];
 
     if (afsdb_handler_shutdown)
 	return -2;
@@ -91,7 +90,7 @@ afs_AFSDBHandler(char *acellName, int acellNameLen, afs_int32 * kernelMsg)
 	if (timeout)
 	    timeout += osi_Time();
 
-	for (i = 0; i < MAXCELLHOSTS; i++) {
+	for (i = 0; i < AFS_MAXCELLHOSTS; i++) {
 	    if (i >= hostCount)
 		cellHosts[i] = 0;
 	    else
@@ -181,7 +180,6 @@ afs_GetCellHostsAFSDB(char *acellName)
     } else
 	return ENOENT;
 }
-#endif
 
 
 /*! 
@@ -191,7 +189,6 @@ afs_GetCellHostsAFSDB(char *acellName)
 void
 afs_LookupAFSDB(char *acellName)
 {
-#ifdef AFS_AFSDB_ENV
     int code;
     char *cellName = afs_strdup(acellName);
 
@@ -199,7 +196,6 @@ afs_LookupAFSDB(char *acellName)
     afs_Trace2(afs_iclSetp, CM_TRACE_AFSDB, ICL_TYPE_STRING, cellName, 
                ICL_TYPE_INT32, code);
     afs_osi_FreeStr(cellName);
-#endif
 }
 
 /*
@@ -943,7 +939,7 @@ afs_NewCell(char *acellName, afs_int32 * acellHosts, int aflags,
     /* we don't want to keep pinging old vlservers which were down,
      * since they don't matter any more.  It's easier to do this than
      * to remove the server from its various hash tables. */
-    for (i = 0; i < MAXCELLHOSTS; i++) {
+    for (i = 0; i < AFS_MAXCELLHOSTS; i++) {
 	if (!tc->cellHosts[i])
 	    break;
 	tc->cellHosts[i]->flags &= ~SRVR_ISDOWN;
@@ -976,7 +972,7 @@ afs_NewCell(char *acellName, afs_int32 * acellHosts, int aflags,
     tc->timeout = timeout;
     
     memset(tc->cellHosts, 0, sizeof(tc->cellHosts));
-    for (i = 0; i < MAXCELLHOSTS; i++) {
+    for (i = 0; i < AFS_MAXCELLHOSTS; i++) {
 	/* Get server for each host and link this cell in.*/	
 	struct server *ts;
 	afs_uint32 temp = acellHosts[i];
@@ -989,7 +985,7 @@ afs_NewCell(char *acellName, afs_int32 * acellHosts, int aflags,
 	tc->cellHosts[i] = ts;
 	afs_PutServer(ts, WRITE_LOCK);
     }
-    afs_SortServers(tc->cellHosts, MAXCELLHOSTS);	/* randomize servers */
+    afs_SortServers(tc->cellHosts, AFS_MAXCELLHOSTS);	/* randomize servers */
 	
     /* New cell: Build and add to LRU cell queue. */
     if (newc) {
@@ -1040,10 +1036,8 @@ void
 afs_CellInit(void)
 {
     AFS_RWLOCK_INIT(&afs_xcell, "afs_xcell");
-#ifdef AFS_AFSDB_ENV
     AFS_RWLOCK_INIT(&afsdb_client_lock, "afsdb_client_lock");
     AFS_RWLOCK_INIT(&afsdb_req_lock, "afsdb_req_lock");
-#endif
     QInit(&CellLRU);
 
     afs_cellindex = 0;
@@ -1100,7 +1094,7 @@ afs_RemoveCellEntry(struct server *srvp)
 
     /* Remove the server structure from the cell list - if there */
     ObtainWriteLock(&tc->lock, 200);
-    for (j = k = 0; j < MAXCELLHOSTS; j++) {
+    for (j = k = 0; j < AFS_MAXCELLHOSTS; j++) {
 	if (!tc->cellHosts[j])
 	    break;
 	if (tc->cellHosts[j] != srvp) {
@@ -1110,7 +1104,7 @@ afs_RemoveCellEntry(struct server *srvp)
     if (k == 0) {
 	/* What do we do if we remove the last one? */
     }
-    for (; k < MAXCELLHOSTS; k++) {
+    for (; k < AFS_MAXCELLHOSTS; k++) {
 	tc->cellHosts[k] = 0;
     }
     ReleaseWriteLock(&tc->lock);
