@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bucoord/main.c,v 1.16.14.6 2009/03/16 13:32:14 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -46,9 +44,14 @@ RCSID
 #include <afs/com_err.h>
 #include <lock.h>
 #include <afs/budb.h>
+#include <afs/kautils.h>
+#include <afs/vlserver.h>
+#include <afs/butm.h>
+#include <afs/butx.h>
+#include <afs/tcdata.h>
 
 #include "bc.h"			/*Backup Coordinator structs and defs */
-#include "bucoord_prototypes.h"
+#include "bucoord_internal.h"
 
 int localauth, interact;
 char tcell[64];
@@ -224,7 +227,7 @@ backupInit(void)
     }
     initd = 1;
 
-    code = bc_InitConfig(DefaultConfDir);
+    code = bc_InitConfig((char *)DefaultConfDir);
     if (code) {
 	afs_com_err(whoami, code,
 		"Can't initialize from config files in directory '%s'",
