@@ -10,8 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/butc/tcmain.c,v 1.16.8.9 2009/03/17 04:45:08 shadow Exp $");
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wimplicit-function-declaration"
+#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -53,6 +54,8 @@ RCSID
 #include <ctype.h>
 #include "error_macros.h"
 #include <afs/budb_errs.h>
+#include <afs/budb_client.h>
+#include <afs/bucoord_prototypes.h>
 #include "afs/butx.h"
 #define XBSA_TCMAIN
 #include "butc_xbsa.h"
@@ -66,7 +69,6 @@ RCSID
 #define CFG_PREFIX "CFG"
 
 struct ubik_client *cstruct;
-extern void TC_ExecuteRequest();
 FILE *logIO, *ErrorlogIO, *centralLogIO, *lastLogIO;
 char lFile[AFSDIR_PATH_MAX];
 char logFile[256];
@@ -112,7 +114,8 @@ afs_uint32 SHostAddrs[ADDRSPERSITE];
 
 /* dummy routine for the audit work.  It should do nothing since audits */
 /* occur at the server level and bos is not a server. */
-osi_audit()
+int
+osi_audit(void)
 {
     return 0;
 }
@@ -124,7 +127,7 @@ SafeATOL(register char *anum)
     register int tc;
 
     total = 0;
-    while (tc = *anum) {
+    while ((tc = *anum)) {
 	if (tc < '0' || tc > '9')
 	    return -1;
 	total *= 10;
@@ -250,7 +253,8 @@ atocl(char *numstring, char crunit, afs_int32 *number)
 }
 
 /* replace last two ocurrences of / by _ */
-static
+#if 0
+static int
 stringReplace(char *name)
 {
     char *pos;
@@ -264,8 +268,9 @@ stringReplace(char *name)
     strcat(name, buffer);
     return 0;
 }
+#endif
 
-static
+static int
 stringNowReplace(char *logFile, char *deviceName)
 {
     char *pos = 0;
@@ -283,7 +288,7 @@ stringNowReplace(char *logFile, char *deviceName)
 	deviceName += devPrefLen;
 	mvFlag++;
     }
-    while (pos = strchr(deviceName, devPrefix[0]))	/* look for / or \ */
+    while ((pos = strchr(deviceName, devPrefix[0])))	/* look for / or \ */
 	*pos = '_';
     strcat(logFile, deviceName);
     /* now put back deviceName to the way it was */
@@ -323,8 +328,8 @@ GetDeviceConfig(char *filename, struct tapeConfig *config, afs_int32 portOffset)
     char devName[LINESIZE], tcapacity[LINESIZE], tfmsize[LINESIZE],
 	trest[LINESIZE];
     afs_int32 aport;
-    afs_uint32 capacity;
-    afs_uint32 fmSize;
+    afs_int32 capacity;
+    afs_int32 fmSize;
     afs_int32 code = 0, count;
 
     /* Initialize the config struct */
@@ -796,7 +801,7 @@ GetConfigParams(char *filename, afs_int32 port)
 	statusSize *= BufferSize;
 	if (statusSize < 0)
 	    statusSize = 0x7fffffff;	/*max size */
-	printf("Status every %ld Bytes\n", afs_cast_int32(statusSize));
+	printf("Status every %ld Bytes\n", afs_printable_int32_ld(statusSize));
     }
 
   error_exit:
