@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rx/rx_misc.c,v 1.13.8.3 2008/01/31 07:31:59 jaltman Exp $");
 
 #ifdef	KERNEL
 #include <afs/sysincludes.h>
@@ -52,9 +50,9 @@ RCSID
  * (network) system error code.
  */
 int
-hton_syserr_conv(register afs_int32 code)
+hton_syserr_conv(afs_int32 code)
 {
-    register afs_int32 err;
+    afs_int32 err;
 
     if (code == ENOSPC)
 	err = VDISKFULL;
@@ -75,7 +73,7 @@ hton_syserr_conv(register afs_int32 code)
 int
 ntoh_syserr_conv(int code)
 {
-    register afs_int32 err;
+    afs_int32 err;
 
     if (code == VDISKFULL)
 	err = ENOSPC;
@@ -106,9 +104,9 @@ ntoh_syserr_conv(int code)
  */
 
 #include <assert.h>
-pthread_mutex_t osi_malloc_mutex;
-#define LOCK_MALLOC_STATS assert(pthread_mutex_lock(&osi_malloc_mutex)==0)
-#define UNLOCK_MALLOC_STATS assert(pthread_mutex_unlock(&osi_malloc_mutex)==0)
+afs_kmutex_t osi_malloc_mutex;
+#define LOCK_MALLOC_STATS MUTEX_ENTER(&osi_malloc_mutex);
+#define UNLOCK_MALLOC_STATS MUTEX_EXIT(&osi_malloc_mutex);
 #else
 #define LOCK_MALLOC_STATS
 #define UNLOCK_MALLOC_STATS
