@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/ubik/recovery.c,v 1.14.4.13 2009/03/20 03:49:04 shadow Exp $");
 
 #include <sys/types.h>
 #include <string.h>
@@ -114,7 +112,7 @@ urecovery_AllBetter(register struct ubik_dbase *adbase, int areadAny)
 {
     register afs_int32 rcode;
 
-    ubik_dprint("allbetter checking\n");
+    ubik_dprint_25("allbetter checking\n");
     rcode = 0;
 
 
@@ -137,7 +135,7 @@ urecovery_AllBetter(register struct ubik_dbase *adbase, int areadAny)
 	rcode = 1;
     }
 
-    ubik_dprint("allbetter: returning %d\n", rcode);
+    ubik_dprint_25("allbetter: returning %d\n", rcode);
     return rcode;
 }
 
