@@ -19,8 +19,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/util/serverLog.c,v 1.33.4.5 2009/02/03 19:42:29 shadow Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
@@ -169,7 +167,7 @@ FSLog(const char *format, ...)
 static void*
 DebugOn(void *param)
 {
-    int loglevel = (int)param;
+    int loglevel = (intptr_t)param;
     if (loglevel == 0) {
 	ViceLog(0, ("Reset Debug levels to 0\n"));
     } else {
@@ -202,9 +200,9 @@ SetDebug_Signal(int signo)
     }
     printLocks = 2;
 #if defined(AFS_PTHREAD_ENV)
-    DebugOn((void *) LogLevel);
+    DebugOn((void *)(intptr_t)LogLevel);
 #else /* AFS_PTHREAD_ENV */
-    IOMGR_SoftSig(DebugOn, (void *) LogLevel);
+    IOMGR_SoftSig(DebugOn, (void *)(intptr_t)LogLevel);
 #endif /* AFS_PTHREAD_ENV */
 
     (void)signal(signo, SetDebug_Signal);	/* on some platforms, this
@@ -220,9 +218,9 @@ ResetDebug_Signal(int signo)
     if (printLocks > 0)
 	--printLocks;
 #if defined(AFS_PTHREAD_ENV)
-    DebugOn((void *) LogLevel);
+    DebugOn((void *)(intptr_t)LogLevel);
 #else /* AFS_PTHREAD_ENV */
-    IOMGR_SoftSig(DebugOn, (void *) LogLevel);
+    IOMGR_SoftSig(DebugOn, (void *)(intptr_t)LogLevel);
 #endif /* AFS_PTHREAD_ENV */
 
     (void)signal(signo, ResetDebug_Signal);	/* on some platforms,
@@ -311,11 +309,7 @@ OpenLog(const char *fileName)
     (void)freopen(fileName, "a", stdout);
     (void)freopen(fileName, "a", stderr);
 #ifdef HAVE_SETVBUF
-#ifdef SETVBUF_REVERSED
-    setvbuf(stderr, _IONBF, NULL, 0);
-#else
     setvbuf(stderr, NULL, _IONBF, 0);
-#endif
 #else
     setbuf(stderr, NULL);
 #endif
