@@ -18,8 +18,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/vfsck/pass1.c,v 1.6.14.1 2009/02/18 17:49:00 shadow Exp $");
 
 #define VICE
 #include <sys/param.h>
@@ -98,7 +96,7 @@ pass1()
     /*
      * Find all allocated blocks.
      */
-    memset((char *)&idesc, 0, sizeof(struct inodesc));
+    memset(&idesc, 0, sizeof(struct inodesc));
     idesc.id_type = ADDR;
     idesc.id_func = pass1check;
     inumber = 0;
