@@ -16,11 +16,10 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/viced/physio.c,v 1.12 2003/07/15 23:17:32 shadow Exp $");
 
 #include <stdio.h>
 #include <errno.h>
+#include <string.h>
 #ifdef AFS_NT40_ENV
 #include <fcntl.h>
 #else
@@ -28,13 +27,6 @@ RCSID
 #include <sys/time.h>
 #include <unistd.h>
 #endif
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <afs/nfs.h>
 #include <afs/assert.h>
 #include <lwp.h>
@@ -51,8 +43,6 @@ RCSID
 #endif
 #define PAGESIZE 2048
 
-extern int LogLevel;
-
 afs_int32 lpErrno, lpCount;
 
 /* returns 0 on success, errno on failure */
@@ -163,13 +153,13 @@ void
 FidZap(DirHandle * file)
 {
     IH_RELEASE(file->dirh_handle);
-    memset((char *)file, 0, sizeof(DirHandle));
+    memset(file, 0, sizeof(DirHandle));
 }
 
 void
 FidZero(DirHandle * file)
 {
-    memset((char *)file, 0, sizeof(DirHandle));
+    memset(file, 0, sizeof(DirHandle));
 }
 
 int
@@ -204,4 +194,5 @@ FidCpy(DirHandle * tofile, DirHandle * fromfile)
 {
     *tofile = *fromfile;
     IH_COPY(tofile->dirh_handle, fromfile->dirh_handle);
+    return 0;
 }
