@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/volser/physio.c,v 1.11.14.1 2007/10/30 15:16:59 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -35,6 +33,7 @@ RCSID
 #include <afs/dir.h>
 #include <afs/ihandle.h>
 #include "vol.h"
+#include "physio.h"
 
 /* returns 0 on success, errno on failure */
 int
@@ -108,7 +107,7 @@ void
 SetSalvageDirHandle(DirHandle * dir, afs_int32 volume, afs_int32 device,
                     Inode inode)
 {
-    private SalvageCacheCheck = 1;
+    private int SalvageCacheCheck = 1;
     memset(dir, 0, sizeof(DirHandle));
 
     dir->dirh_volume = volume;
