@@ -16,24 +16,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/xstat/xstat_cm_test.c,v 1.11 2006/04/04 20:51:24 shadow Exp $");
 
 #include "xstat_cm.h"		/*Interface for xstat_cm module */
-#include <cmd.h>		/*Command line interpreter */
+#include <afs/cmd.h>		/*Command line interpreter */
 #include <time.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
-
-/*
- * External routines that don't have explicit include file definitions.
- */
-extern struct hostent *hostutil_GetHostByName();
+#include <afs/afsutil.h>
 
 /*
  * Command line parameter indices.
@@ -124,10 +112,9 @@ static char *xferOpNames[] = {
  *------------------------------------------------------------------------*/
 
 void
-PrintCallInfo()
+PrintCallInfo(void)
 {				/*PrintCallInfo */
 
-    static char rn[] = "PrintCallInfo";	/*Routine name */
     register int i;		/*Loop variable */
     int numInt32s;		/*# int32words returned */
     afs_int32 *currInt32;	/*Ptr to current afs_int32 value */
@@ -147,7 +134,7 @@ PrintCallInfo()
 	 xstat_cm_Results.probeNum, printableTime);
 
     if (debugging_on)
-	printf("\n[%d entries returned at 0x%x]\n\n", numInt32s, currInt32);
+	printf("\n[%d entries returned at %" AFS_PTR_FMT "]\n\n", numInt32s, currInt32);
 
     for (i = 0; i < numInt32s; i++)
 	printf("%d ", *currInt32++);
@@ -158,9 +145,9 @@ PrintCallInfo()
 
 /* Print detailed functional call statistics */
 
-print_cmCallStats()
+void
+print_cmCallStats(void)
 {
-    static char rn[] = "print_cmCallStats";	/*Routine name */
     char *printableTime;	/*Ptr to printable time string */
     struct afs_CMStats *cmp;
     time_t probeTime = xstat_cm_Results.probeTime;
@@ -641,9 +628,7 @@ print_cmCallStats()
  *------------------------------------------------------------------------*/
 
 void
-PrintUpDownStats(a_upDownP)
-     struct afs_stats_SrvUpDownInfo *a_upDownP;	/*Ptr to server up/down info */
-
+PrintUpDownStats(struct afs_stats_SrvUpDownInfo *a_upDownP)
 {				/*PrintUpDownStats */
 
     /*
@@ -707,9 +692,7 @@ PrintUpDownStats(a_upDownP)
  *------------------------------------------------------------------------*/
 
 void
-PrintOverallPerfInfo(a_ovP)
-     struct afs_stats_CMPerf *a_ovP;
-
+PrintOverallPerfInfo(struct afs_stats_CMPerf *a_ovP)
 {				/*PrintOverallPerfInfo */
 
     printf("\t%10d numPerfCalls\n", a_ovP->numPerfCalls);
@@ -798,10 +781,9 @@ PrintOverallPerfInfo(a_ovP)
  *------------------------------------------------------------------------*/
 
 void
-PrintPerfInfo()
+PrintPerfInfo(void)
 {				/*PrintPerfInfo */
 
-    static char rn[] = "PrintPerfInfo";	/*Routine name */
     static afs_int32 perfInt32s = (sizeof(struct afs_stats_CMPerf) >> 2);	/*Correct # int32s to rcv */
     afs_int32 numInt32s;	/*# int32words received */
     struct afs_stats_CMPerf *perfP;	/*Ptr to performance stats */
@@ -853,20 +835,17 @@ PrintPerfInfo()
  *------------------------------------------------------------------------*/
 
 void
-PrintOpTiming(a_opIdx, a_opNames, a_opTimeP)
-     int a_opIdx;
-     char *a_opNames[];
-     struct afs_stats_opTimingData *a_opTimeP;
-
+PrintOpTiming(int a_opIdx, char *a_opNames[],
+	      struct afs_stats_opTimingData *a_opTimeP)
 {				/*PrintOpTiming */
 
     printf
-	("%15s: %d ops (%d OK); sum=%d.%06d, sqr=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	("%15s: %d ops (%d OK); sum=%ld.%06ld, sqr=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	 a_opNames[a_opIdx], a_opTimeP->numOps, a_opTimeP->numSuccesses,
-	 a_opTimeP->sumTime.tv_sec, a_opTimeP->sumTime.tv_usec,
-	 a_opTimeP->sqrTime.tv_sec, a_opTimeP->sqrTime.tv_usec,
-	 a_opTimeP->minTime.tv_sec, a_opTimeP->minTime.tv_usec,
-	 a_opTimeP->maxTime.tv_sec, a_opTimeP->maxTime.tv_usec);
+	 (long)a_opTimeP->sumTime.tv_sec, (long)a_opTimeP->sumTime.tv_usec,
+	 (long)a_opTimeP->sqrTime.tv_sec, (long)a_opTimeP->sqrTime.tv_usec,
+	 (long)a_opTimeP->minTime.tv_sec, (long)a_opTimeP->minTime.tv_usec,
+	 (long)a_opTimeP->maxTime.tv_sec, (long)a_opTimeP->maxTime.tv_usec);
 
 }				/*PrintOpTiming */
 
@@ -893,20 +872,17 @@ PrintOpTiming(a_opIdx, a_opNames, a_opTimeP)
  *------------------------------------------------------------------------*/
 
 void
-PrintXferTiming(a_opIdx, a_opNames, a_xferP)
-     int a_opIdx;
-     char *a_opNames[];
-     struct afs_stats_xferData *a_xferP;
-
+PrintXferTiming(int a_opIdx, char *a_opNames[],
+		struct afs_stats_xferData *a_xferP)
 {				/*PrintXferTiming */
 
     printf
-	("%s: %d xfers (%d OK), time sum=%d.%06d, sqr=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	("%s: %d xfers (%d OK), time sum=%ld.%06ld, sqr=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	 a_opNames[a_opIdx], a_xferP->numXfers, a_xferP->numSuccesses,
-	 a_xferP->sumTime.tv_sec, a_xferP->sumTime.tv_usec,
-	 a_xferP->sqrTime.tv_sec, a_xferP->sqrTime.tv_usec,
-	 a_xferP->minTime.tv_sec, a_xferP->minTime.tv_usec,
-	 a_xferP->maxTime.tv_sec, a_xferP->maxTime.tv_usec);
+	 (long)a_xferP->sumTime.tv_sec, (long)a_xferP->sumTime.tv_usec,
+	 (long)a_xferP->sqrTime.tv_sec, (long)a_xferP->sqrTime.tv_usec,
+	 (long)a_xferP->minTime.tv_sec, (long)a_xferP->minTime.tv_usec,
+	 (long)a_xferP->maxTime.tv_sec, (long)a_xferP->maxTime.tv_usec);
     printf("\t[bytes: sum=%d, min=%d, max=%d]\n", a_xferP->sumBytes,
 	   a_xferP->minBytes, a_xferP->maxBytes);
     printf
@@ -941,11 +917,8 @@ PrintXferTiming(a_opIdx, a_opNames, a_xferP)
  *------------------------------------------------------------------------*/
 
 void
-PrintErrInfo(a_opIdx, a_opNames, a_opErrP)
-     int a_opIdx;
-     char *a_opNames[];
-     struct afs_stats_RPCErrors *a_opErrP;
-
+PrintErrInfo(int a_opIdx, char *a_opNames[],
+	     struct afs_stats_RPCErrors *a_opErrP)
 {				/*PrintErrInfo */
 
     printf
@@ -977,9 +950,7 @@ PrintErrInfo(a_opIdx, a_opNames, a_opErrP)
  *------------------------------------------------------------------------*/
 
 void
-PrintRPCPerfInfo(a_rpcP)
-     struct afs_stats_RPCOpInfo *a_rpcP;
-
+PrintRPCPerfInfo(struct afs_stats_RPCOpInfo *a_rpcP)
 {				/*PrintRPCPerfInfo */
 
     int currIdx;		/*Loop variable */
@@ -1027,12 +998,11 @@ PrintRPCPerfInfo(a_rpcP)
  *------------------------------------------------------------------------*/
 
 void
-PrintFullPerfInfo()
+PrintFullPerfInfo(void)
 {				/*PrintFullPerfInfo */
 
     struct afs_stats_AuthentInfo *authentP;	/*Ptr to authentication stats */
     struct afs_stats_AccessInfo *accessinfP;	/*Ptr to access stats */
-    struct afs_stats_AuthorInfo *authorP;	/*Ptr to authorship stats */
     static afs_int32 fullPerfInt32s = (sizeof(struct afs_stats_CMFullPerf) >> 2);	/*Correct #int32s */
     afs_int32 numInt32s;	/*# int32s actually received */
     struct afs_stats_CMFullPerf *fullP;	/*Ptr to full perf info */
@@ -1119,7 +1089,7 @@ PrintFullPerfInfo()
  *------------------------------------------------------------------------*/
 
 int
-CM_Handler()
+CM_Handler(void)
 {				/*CM_Handler */
 
     static char rn[] = "CM_Handler";	/*Routine name */
@@ -1187,9 +1157,7 @@ CM_Handler()
  *------------------------------------------------------------------------*/
 
 static int
-CountListItems(a_firstItem)
-     struct cmd_item *a_firstItem;
-
+CountListItems(struct cmd_item *a_firstItem)
 {				/*CountListItems */
 
     int list_len;		/*List length */
@@ -1238,9 +1206,7 @@ CountListItems(a_firstItem)
  *------------------------------------------------------------------------*/
 
 int
-RunTheTest(a_s)
-     struct cmd_syndesc *a_s;
-
+RunTheTest(struct cmd_syndesc *a_s, void *arock)
 {				/*RunTheTest */
 
     static char rn[] = "RunTheTest";	/*Routine name */
@@ -1383,8 +1349,8 @@ RunTheTest(a_s)
 	 * One-shot operation; just wait for the collection to be done.
 	 */
 	if (debugging_on)
-	    printf("[%s] Calling LWP_WaitProcess() on event 0x%x\n", rn,
-		   &terminationEvent);
+	    printf("[%s] Calling LWP_WaitProcess() on event %" AFS_PTR_FMT
+		   "\n", rn, &terminationEvent);
 	waitCode = LWP_WaitProcess(&terminationEvent);
 	if (debugging_on)
 	    printf("[%s] Returned from LWP_WaitProcess()\n", rn);
@@ -1434,11 +1400,8 @@ RunTheTest(a_s)
 
 
 #include "AFS_component_version_number.c"
-
-main(argc, argv)
-     int argc;
-     char **argv;
-
+int
+main(int argc, char **argv)
 {				/*Main routine */
 
     static char rn[] = "xstat_cm_test";	/*Routine name */
@@ -1448,7 +1411,7 @@ main(argc, argv)
     /*
      * Set up the commands we understand.
      */
-    ts = cmd_CreateSyntax("initcmd", RunTheTest, 0, "initialize the program");
+    ts = cmd_CreateSyntax("initcmd", RunTheTest, NULL, "initialize the program");
     cmd_AddParm(ts, "-cmname", CMD_LIST, CMD_REQUIRED,
 		"Cache Manager name(s) to monitor");
     cmd_AddParm(ts, "-collID", CMD_LIST, CMD_REQUIRED,
